@@ -15,21 +15,13 @@
 #' \code{mean2(..., refine = FALSE)} is almost twice as fast as
 #' \code{mean2(..., refine = TRUE)}.
 #'
-#' @param x A \code{\link[base]{numeric}} or \code{\link[base]{logical}}
-#' \code{\link[base]{vector}} of length N.
-#'
-#' @param idxs A \code{\link[base]{vector}} indicating subset of elements to
-#' operate over. If \code{\link[base]{NULL}}, no subsetting is done.
-#'
-#' @param na.rm If \code{\link[base:logical]{TRUE}}, missing values are
-#' skipped, otherwise not.
+#' @inheritParams rowAlls
+#' @inheritParams weightedMad
 #'
 #' @param refine If \code{\link[base:logical]{TRUE}} and \code{x} is
 #' \code{\link[base]{numeric}}, then extra effort is used to calculate the
 #' average with greater numerical precision, otherwise not.
 #'
-#' @param ... Not used.
-#'
 #' @return Returns a \code{\link[base]{numeric}} scalar.
 #'
 #' @example incl/mean2.R
@@ -46,17 +38,17 @@ mean2 <- function(x, idxs = NULL, na.rm = FALSE, refine = TRUE, ...) {
   # - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - -
   # Argument 'x':
   if (!is.numeric(x) && !is.logical(x)) {
-    stop("Argument 'x' is neither numeric nor logical: ", mode(x))
+    stop(sprintf("Argument '%s' is not numeric or logical: %s", "x", mode(x)))
   }
 
   # Argument 'na.rm':
   if (!is.logical(na.rm)) {
-    stop("Argument 'na.rm' is not logical: ", mode(na.rm))
+    stop(sprintf("Argument '%s' is not logical: %s", "na.rm", mode(na.rm)))
   }
 
   # Argument 'refine':
   if (!is.logical(refine)) {
-    stop("Argument 'refine' is not logical: ", mode(refine))
+    stop(sprintf("Argument '%s' is not logical: %s", "refine", mode(refine)))
   }
 
   # - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - -
@@ -64,9 +56,3 @@ mean2 <- function(x, idxs = NULL, na.rm = FALSE, refine = TRUE, ...) {
   # - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - -
   .Call(C_mean2, x, idxs, na.rm, refine)
 }
-
-#' @rdname mean2
-#' @export
-meanOver <- function(...) {
-  .Defunct(new = "mean2")
-}
