@@ -4,17 +4,19 @@
 #' @export
 rowMads <- function(x, rows = NULL, cols = NULL, center = NULL,
                     constant = 1.4826, na.rm = FALSE,
-                    dim. = dim(x), ...) {
+                    dim. = dim(x), ..., useNames = NA) {
   if (is.null(center)) {
-    dim. <- as.integer(dim.)
-    na.rm <- as.logical(na.rm)
     constant <- as.numeric(constant)
     has_nas <- TRUE
-    x <- .Call(C_rowMads, x, dim., rows, cols, constant, na.rm, has_nas, TRUE)
+    
+    x <- .Call(C_rowMads, x, dim., rows, cols, constant, na.rm, has_nas, TRUE, useNames)
   } else {
     ## https://github.com/HenrikBengtsson/matrixStats/issues/187
     centerOnUse("rowMads")
     
+    # Preserve names
+    names <- rownames(x)
+    
     # Apply new dimensions
     if (!identical(dim(x), dim.)) dim(x) <- dim.
     
@@ -23,7 +25,7 @@ rowMads <- function(x, rows = NULL, cols = NULL, center = NULL,
       if (length(center) == 1L && is.null(rows)) {
         validateScalarCenter(center, nrow(x), "rows")
       } else {
-        stop("Argument 'center' should be of the same length as number of rows of 'x': ", length(center), " != ", nrow(x))
+        stop(sprintf("Argument '%s' should be of the same length as number of %s of '%s': %d != %d", "center", "rows", "x", length(center), nrow(x)))
       }
     }
     if (!is.null(rows)) center <- center[rows]
@@ -35,11 +37,23 @@ rowMads <- function(x, rows = NULL, cols = NULL, center = NULL,
     dim. <- dim(x)
 
     x <- x - center
-    if (is.null(dim(x))) dim(x) <- dim. # prevent from dim dropping
+    if (is.null(dim(x))) {
+      dim(x) <- dim. # prevent from dim dropping
+      # Preserve names attribute?
+      if (!is.na(useNames) && useNames) {
+        if (!is.null(names)) {
+          if (!is.null(rows)) {
+            names <- names[rows]
+          }
+          rownames(x) <- names
+        }
+      }      
+    }
     x <- abs(x)
-    x <- rowMedians(x, na.rm = na.rm, ...)
+    x <- rowMedians(x, na.rm = na.rm, ..., useNames = useNames)
     x <- constant * x
   }
+
   x
 }
 
@@ -48,17 +62,19 @@ rowMads <- function(x, rows = NULL, cols = NULL, center = NULL,
 #' @export
 colMads <- function(x, rows = NULL, cols = NULL, center = NULL,
                     constant = 1.4826, na.rm = FALSE,
-                    dim. = dim(x), ...) {
+                    dim. = dim(x), ..., useNames = NA) {
   if (is.null(center)) {
-    dim. <- as.integer(dim.)
-    na.rm <- as.logical(na.rm)
     constant <- as.numeric(constant)
     has_nas <- TRUE
-    x <- .Call(C_rowMads, x, dim., rows, cols, constant, na.rm, has_nas, FALSE)
+    
+    x <- .Call(C_rowMads, x, dim., rows, cols, constant, na.rm, has_nas, FALSE, useNames)
   } else {
     ## https://github.com/HenrikBengtsson/matrixStats/issues/187
     centerOnUse("colMads")
     
+    # Preserve names
+    names <- colnames(x)
+    
     # Apply new dimensions
     if (!identical(dim(x), dim.)) dim(x) <- dim.
     
@@ -67,7 +83,7 @@ colMads <- function(x, rows = NULL, cols = NULL, center = NULL,
       if (length(center) == 1L && is.null(cols)) {
         validateScalarCenter(center, ncol(x), "columns")
       } else {
-        stop("Argument 'center' should be of the same length as number of columns of 'x': ", length(center), " != ", ncol(x))
+        stop(sprintf("Argument '%s' should be of the same length as number of %s of '%s': %d != %d", "center", "columns", "x", length(center), ncol(x)))
       }
     }
     if (!is.null(cols)) center <- center[cols]
@@ -84,9 +100,25 @@ colMads <- function(x, rows = NULL, cols = NULL, center = NULL,
     # }
     ## FAST:
     x <- t_tx_OP_y(x, center, OP = "-", na.rm = FALSE)
+    # Preserve names attribute?
+    if (!is.na(useNames)) {
+      if (useNames) {
+        if (!is.null(names)) {
+          if (!is.null(cols)) {
+            names <- names[cols]
+            # Zero-length attribute? Keep behavior same as base R function
+            if (length(names) == 0L) names <- NULL         
+          }
+          colnames(x) <- names
+        }
+      } else {
+        colnames(x) <- NULL
+      }
+    }
     x <- abs(x)
-    x <- colMedians(x, na.rm = na.rm, ...)
+    x <- colMedians(x, na.rm = na.rm, ..., useNames = useNames)
     x <- constant * x
   }
+
   x
 }
