@@ -6,17 +6,9 @@
 #' memory.  If no weights are given, the corresponding
 #' \code{\link{rowMedians}}()/\code{colMedians()} is used.
 #'
-#' @param x A \code{\link[base]{numeric}} NxK \code{\link[base]{matrix}}.
-#'
-#' @param w A \code{\link[base]{numeric}} \code{\link[base]{vector}} of length
-#' K (N).
-#'
-#' @param rows,cols A \code{\link[base]{vector}} indicating subset of rows
-#' (and/or columns) to operate over. If \code{\link[base]{NULL}}, no subsetting
-#' is done.
-#'
-#' @param na.rm If \code{\link[base:logical]{TRUE}}, missing values are
-#' excluded from the calculation, otherwise not.
+#' @inheritParams rowAlls
+#' @inheritParams rowDiffs
+#' @inheritParams rowWeightedMeans
 #'
 #' @param ... Additional arguments passed to \code{\link{weightedMedian}}().
 #'
@@ -27,32 +19,32 @@
 #'
 #' @author Henrik Bengtsson
 #'
-#' @seealso See \code{\link{rowMedians}}() and \code{colMedians()} for
-#' non-weighted medians.  Internally, \code{\link{weightedMedian}}() is used.
+#' @seealso Internally, \code{\link{weightedMedian}}() is used.
+#' See \code{\link{rowMedians}}() and \code{colMedians()} for non-weighted
+#' medians.
+#' 
 #' @keywords array iteration robust univar
 #' @export
 rowWeightedMedians <- function(x, w = NULL, rows = NULL, cols = NULL,
-                               na.rm = FALSE, ...) {
+                               na.rm = FALSE, ..., useNames = NA) {
   # - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - -
   # Validate arguments
   # - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - -
   # Argument 'x':
-  if (!is.matrix(x)) {
-    .Deprecated(msg = sprintf("Argument 'x' is of class %s, but should be a matrix. The use of a %s is not supported, the correctness of the result is not guaranteed, and will be defunct (produce an error) in a future version of matrixStats. Please update your code accordingly.", sQuote(class(x)[1]), sQuote(class(x)[1])))  #nolint
-  }
+  if (!is.matrix(x)) defunctShouldBeMatrix(x)
 
   # Argument 'w':
   has_weights <- !is.null(w)
   if (has_weights) {
     n <- ncol(x)
     if (length(w) != n) {
-      stop("The length of argument 'w' is does not match the number of column in 'x': ", length(w), " != ", n)  #nolint
+      stop(sprintf("The length of argument '%s' does not match the number of %s in '%s': %d != %d", "w", "columns", "x", length(w), n))  #nolint
     }
     if (!is.numeric(w)) {
-      stop("Argument 'w' is not numeric: ", mode(w))
+      stop(sprintf("Argument '%s' is not numeric: %s", "w", mode(w)))
     }
     if (any(!is.na(w) & w < 0)) {
-      stop("Argument 'w' has negative weights.")
+      stop(sprintf("Argument '%s' must not contain negative values", "w"))
     }
   }
 
@@ -74,10 +66,15 @@ rowWeightedMedians <- function(x, w = NULL, rows = NULL, cols = NULL,
     res <- apply(x, MARGIN = 1L, FUN = function(x) {
       weightedMedian(x, w = w, na.rm = na.rm, ...)
     })
+    
+    # Preserve names attribute?
+    if (!(is.na(useNames) || useNames)) {
+      names(res) <- NULL
+    }
 
     w <- NULL  # Not needed anymore
   } else {
-    res <- rowMedians(x, na.rm = na.rm)
+    res <- rowMedians(x, na.rm = na.rm, useNames = useNames)
   }
 
   res
@@ -87,27 +84,25 @@ rowWeightedMedians <- function(x, w = NULL, rows = NULL, cols = NULL,
 #' @rdname rowWeightedMedians
 #' @export
 colWeightedMedians <- function(x, w = NULL, rows = NULL, cols = NULL,
-                               na.rm = FALSE, ...) {
+                               na.rm = FALSE, ..., useNames = NA) {
   # - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - -
   # Validate arguments
   # - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - -
   # Argument 'x':
-  if (!is.matrix(x)) {
-    .Deprecated(msg = sprintf("Argument 'x' is of class %s, but should be a matrix. The use of a %s is not supported, the correctness of the result is not guaranteed, and will be defunct (produce an error) in a future version of matrixStats. Please update your code accordingly.", sQuote(class(x)[1]), sQuote(class(x)[1])))  #nolint
-  }
+  if (!is.matrix(x)) defunctShouldBeMatrix(x)
 
   # Argument 'w':
   has_weights <- !is.null(w)
   if (has_weights) {
     n <- nrow(x)
     if (length(w) != n) {
-      stop("The length of argument 'w' is does not match the number of rows in 'x': ", length(w), " != ", n)  #nolint
+      stop(sprintf("The length of argument '%s' does not match the number of %s in '%s': %d != %d", "w", "rows", "x", length(w), n))  #nolint
     }
     if (!is.numeric(w)) {
-      stop("Argument 'w' is not numeric: ", mode(w))
+      stop(sprintf("Argument '%s' is not numeric: %s", "w", mode(w)))
     }
     if (any(!is.na(w) & w < 0)) {
-      stop("Argument 'w' has negative weights.")
+      stop(sprintf("Argument '%s' must not contain negative values", "w"))
     }
   }
 
@@ -128,10 +123,15 @@ colWeightedMedians <- function(x, w = NULL, rows = NULL, cols = NULL,
     res <- apply(x, MARGIN = 2L, FUN = function(x) {
       weightedMedian(x, w = w, na.rm = na.rm, ...)
     })
+    
+    # Preserve names attribute?
+    if (!(is.na(useNames) || useNames)) {
+      names(res) <- NULL
+    }
 
     w <- NULL  # Not needed anymore
   } else {
-    res <- colMedians(x, na.rm = na.rm)
+    res <- colMedians(x, na.rm = na.rm, useNames = useNames)
   }
 
   res
