@@ -56,9 +56,9 @@ double CONCAT_MACROS(mean2, X_C_SIGNATURE)(X_C_TYPE *x, R_xlen_t nx, R_xlen_t *i
 #endif
   } /* for (i ...) */
 
-  if (sum > DOUBLE_XMAX) {
+  if (sum > DBL_MAX) {
     avg = R_PosInf;
-  } else if (sum < -DOUBLE_XMAX) {
+  } else if (sum < -DBL_MAX) {
     avg = R_NegInf;
   } else {
     avg = sum / count;
