@@ -16,7 +16,7 @@ SEXP weightedMedian(SEXP x, SEXP w, SEXP idxs, SEXP naRm, SEXP interpolate, SEXP
   R_xlen_t nx, nw;
 
   /* Argument 'x': */
-  assertArgVector(x, (R_TYPE_INT | R_TYPE_REAL), "x");
+  assertArgVector(x, (R_TYPE_LGL | R_TYPE_INT | R_TYPE_REAL), "x");
   nx = xlength(x);
 
   /* Argument 'x': */
@@ -34,17 +34,16 @@ SEXP weightedMedian(SEXP x, SEXP w, SEXP idxs, SEXP naRm, SEXP interpolate, SEXP
 
   /* Argument 'idxs': */
   R_xlen_t nidxs;
-  int idxsType;
-  void *cidxs = validateIndices(idxs, nx, 1, &nidxs, &idxsType);
+  R_xlen_t *cidxs = validateIndices(idxs, nx, 1, &nidxs);
 
   /* Argument 'ties': */
   ties2 = asInteger(ties);
 
   /* Double matrices are more common to use. */
   if (isReal(x)) {
-    mu = weightedMedian_dbl[idxsType](REAL(x), nx, REAL(w), cidxs, nidxs, narm, interpolate2, ties2);
-  } else if (isInteger(x)) {
-    mu = weightedMedian_int[idxsType](INTEGER(x), nx, REAL(w), cidxs, nidxs, narm, interpolate2, ties2);
+    mu = weightedMedian_dbl(REAL(x), nx, REAL(w), cidxs, nidxs, narm, interpolate2, ties2);
+  } else if (isInteger(x) | isLogical(x)) {
+    mu = weightedMedian_int(INTEGER(x), nx, REAL(w), cidxs, nidxs, narm, interpolate2, ties2);
   }
 
   /* Return results */
