@@ -3,7 +3,7 @@
 if  (getRversion() >= "3.0.2" && Sys.getenv("_R_CHECK_USE_VALGRIND_") == "") {
 
 ## 3. Make sure all suggested packages are installed / can be loaded
-pkgs <- c("base64enc", "ggplot2", "knitr", "microbenchmark",
+pkgs <- c("base64enc", "ggplot2", "knitr", "markdown", "microbenchmark",
           "R.devices", "R.rsp")
 if (all(unlist(lapply(pkgs, FUN = requireNamespace)))) {
   html <- matrixStats:::benchmark("binCounts")
